==> haskell-getopt-generics-0.13.0.4-159-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-getopt-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 getopt-generics
version:              0.13.0.4
visibility:           public
id:                   getopt-generics-0.13.0.4-GbKLxDsGtI67pvnPOrBc7o
key:                  getopt-generics-0.13.0.4-GbKLxDsGtI67pvnPOrBc7o
license:              BSD-3-Clause
copyright:            Zalora South East Asia Pte Ltd
maintainer:           linh.nguyen@zalora.com, soenkehahn@gmail.com
author:               Linh Nguyen, Sönke Hahn
homepage:             https://github.com/soenkehahn/getopt-generics#readme
synopsis:             Create command line interfaces with ease
description:          Create command line interfaces with ease
category:             Console, System
abi:                  35229219006ef81c54d31ed28599b7c8
exposed:              True
exposed-modules:      WithCli WithCli.Pure
hidden-modules:
    WithCli.Argument WithCli.Flag WithCli.HasArguments WithCli.Modifier
    WithCli.Modifier.Types WithCli.Normalize WithCli.Parser
    WithCli.Pure.Internal WithCli.Result Paths_getopt_generics

import-dirs:          /usr/lib/ghc-9.0.2/site-local/getopt-generics-0.13.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/getopt-generics-0.13.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-getopt-generics
hs-libraries:         HSgetopt-generics-0.13.0.4-GbKLxDsGtI67pvnPOrBc7o
depends:
    base-4.15.1.0 base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu
    base-orphans-0.8.7-ExGEIraIdYM5imPv9ZUf9M
    generics-sop-0.5.1.2-GuW3tW9POUeDgjnWWI6XmZ
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:
    /usr/share/doc/haskell-getopt-generics/html/getopt-generics.haddock

haddock-html:         /usr/share/doc/haskell-getopt-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-getopt-generics-0.13.0.4-161-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-getopt-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 getopt-generics
version:              0.13.0.4
visibility:           public
id:                   getopt-generics-0.13.0.4-GIc9IO8FVZB8HbSpPhC3L
key:                  getopt-generics-0.13.0.4-GIc9IO8FVZB8HbSpPhC3L
license:              BSD-3-Clause
copyright:            Zalora South East Asia Pte Ltd
maintainer:           linh.nguyen@zalora.com, soenkehahn@gmail.com
author:               Linh Nguyen, Sönke Hahn
homepage:             https://github.com/soenkehahn/getopt-generics#readme
synopsis:             Create command line interfaces with ease
description:          Create command line interfaces with ease
category:             Console, System
abi:                  211851a54297265aba28e9b58dbbe493
exposed:              True
exposed-modules:      WithCli WithCli.Pure
hidden-modules:
    WithCli.Argument WithCli.Flag WithCli.HasArguments WithCli.Modifier
    WithCli.Modifier.Types WithCli.Normalize WithCli.Parser
    WithCli.Pure.Internal WithCli.Result Paths_getopt_generics

import-dirs:          /usr/lib/ghc-9.0.2/site-local/getopt-generics-0.13.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/getopt-generics-0.13.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-getopt-generics
hs-libraries:         HSgetopt-generics-0.13.0.4-GIc9IO8FVZB8HbSpPhC3L
depends:
    base-4.15.1.0 base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu
    base-orphans-0.8.7-9SGCOegMytyDm0Z732zi6I
    generics-sop-0.5.1.2-GuW3tW9POUeDgjnWWI6XmZ
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:
    /usr/share/doc/haskell-getopt-generics/html/getopt-generics.haddock

haddock-html:         /usr/share/doc/haskell-getopt-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
